OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Приватност",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Центар за приватност приказује где су Ваши подаци ускладиштени и ко може да им приступ, или зато што сте их Ви поделили са њима, или зато што су администратори.",
    "Administrators" : "Администратори",
    "The following accounts are designated administrators and may potentially have access to your data through system storage or backups. However, they do not have easy access to your data via the web interface or client applications." : "Следећи налози су одређени за администраторе и потенцијално могу да имају приступ вашим подацима кроз системско складиште или резервне копије. Међутим, они немају једноставни приступ вашим подацима кроз веб интерфејс или клијентске апликације.",
    "Loading administrators …" : "Учитавају се адмнистратори",
    "Remove external {propertyName} admin" : "Уклони спољног {propertyName} админа",
    "Add external admin" : "Додај спољног администратора",
    "Cancel" : "Откажи",
    "Add" : "Додај",
    "Name of external admin" : "Име спољног администратора",
    "Error loading additional administrator." : "Грешка приликом учитавања додатног администратора.",
    "Error adding new administrator." : "Грешка приликом додавања додатног администратора.",
    "Error deleting new administrator." : "Грешка приликом брисања додатног администратора.",
    "Encryption" : "Шифровање",
    "Edit encryption" : "Уреди шифрирање",
    "Edit" : "Измени",
    "This server is using full-disk-encryption." : "Овај сервер користи шифровање целог диска.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "Ваше лично складиште је шифрирано {linkopen}енкрипцијом на страни сервера ↗{linkclose} уз употребу главног кључа. То значи да администратори могу да приступе вашим фајловима, али не могу да прочитају њихов садржај.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Ваши фајлови на спољним складиштима могу бити шифрирани {linkopen}енкрипцијом на страни сервера ↗{linkclose} уз употребу главног кључа у зависности од тога како су конфигурисана.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "Ваше лично складиште се шифрира {linkopen}екрипцијом на страни сервера ↗{linkclose} уз употребу индивидуалног корисничког кључа. То значи да администратори могу да приступе вашим фајловима, али не могу да прочитају њихов садржај.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Ваши фајлови на спољним складиштима могу бити шифрирани {linkopen}енкрипцијом на страни севера ↗{linkclose} уз употребу индивидуалног кључа, у зависности од тога како су конфигурисана.",
    "Additionally, this server is protected with full-disk-encryption." : "Уз то, овај сервер је заштићен шифрирањем комплетних дискова.",
    "This server is protected with full-disk-encryption." : "Овај сервер је заштићен са шифровањем целог диска.",
    "Your files are not protected by encryption." : "Ваши фајлови нису заштићени шифровањем.",
    "Error saving new state of full-disk-encryption" : "Грешка приликом чувања новог стања шифрирања комплетног диска",
    "Privacy policy" : "Политика приватност",
    "Read the privacy policy ↗" : "Прочитајте политику приватности ↗",
    "People you've shared with" : "Људи са којима делите",
    "Loading people you've shared with …" : "Учитавају се људи са којима делите…",
    "You do not have any shares with individual users." : "Немате ниједно дељење са појединачним корисницима.",
    "Error loading information about shares." : "Грешка приликом учитавања информација у вези са дељењима.",
    "Who has access to your data?" : "Ко има приступ Вашим подацима?",
    "Where is your data?" : "Где су Ваши подаци?",
    "Your data is located in:" : "Ваши подаци се налазе у:",
    "An admin has not selected the location of the server yet." : "Админ још увек није поставио локацију сервера.",
    "Change data location" : "Промени локацију података",
    "Region" : "Регија",
    "Please select a region" : "Молимо одаберите регију",
    "Error saving new location of the server" : "Грешка приликом чувања нове локације сервера",
    "User Data Manifesto 2.0" : "Манифест корисничких података 2.0",
    "Defining basic rights for people to control their own data in the internet age." : "Дефинисање основних права људи за контролу сопствених података у добу интернета.",
    "Control" : "Контрола",
    "over user data access" : "над приступом корисничким подацима",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Подаци који се експлицитно и својевољно отпреме од стране корисника морају бити под крајњом контролом тог корисника. Корисници треба да су у могућности да изаберу коме ће дати директан приступ подацима, и под којим дозволама и лиценцама ће такав приступ бити дат.",
    "Knowledge" : "Разумевање",
    "of how the data is stored" : "како се подаци складиште",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Када се подаци отпреме одређеном провајдеру сервиса, корисници морају бити упућени где тај провајдер држи податке, колико дуго, под чијом правном надлежности провајдер ради и који закони се примењују.",
    "Freedom" : "Слобода",
    "to choose a platform" : "одабира платформе",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Корисници морају увек бити у могућности да извуку своје податке са сервера без да искусе закључавање од стране продавца. Да би се ово гарантовало, неопходни су отворени формати и протоколи.",
    "Learn more ↗" : "Сазнајте више ↗",
    "Your {serverName} account" : "Ваш {serverName} налог",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Ваши подаци представљају ко сте Ви и лако могу бити злоупотребљени. Ми у Некстклауду верујемо да имате права да изаберете шта се дешава са Вашим подацима. Некстклауд штити ваша права као што је дефинисано у манифесту корисничких података!",
    "Somaliland" : "Сомалиланд",
    "Andorra" : "Андора",
    "United Arab Emirates" : "Уједињени Арапски Емирати",
    "Afghanistan" : "Авганистан",
    "Antigua and Barbuda" : "Антигва и Барбуда",
    "Anguilla" : "Ангвила",
    "Albania" : "Албанија",
    "Armenia" : "Јерменија",
    "Angola" : "Ангола",
    "Antarctica" : "Антарктик",
    "Argentina" : "Аргентина",
    "American Samoa" : "Америчка Самоа",
    "Austria" : "Аустрија",
    "Australia" : "Аустралија",
    "Aruba" : "Аруба",
    "Åland Islands" : "Оландска острва",
    "Azerbaijan" : "Азербејџан",
    "Bosnia and Herzegovina" : "Босна и Херцеговина",
    "Barbados" : "Барбадос",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Белгија",
    "Burkina Faso" : "Буркина Фасо",
    "Bulgaria" : "Бугарска",
    "Bahrain" : "Бахреин",
    "Burundi" : "Бурунди",
    "Benin" : "Бенин",
    "Saint Barthélemy" : "Сент Бартелеми",
    "Bermuda" : "Бермуда",
    "Brunei" : "Брунеј",
    "Bolivia" : "Боливија",
    "Bonaire, Sint Eustatius and Saba" : "Карипска Холандија",
    "Brazil" : "Бразил",
    "Bahamas" : "Бахами",
    "Bhutan" : "Бутан",
    "Bouvet Island" : "Буве",
    "Botswana" : "Боцвана",
    "Belarus" : "Белорусија",
    "Belize" : "Белизе",
    "Canada" : "Канада",
    "Cocos (Keeling) Islands" : "Кокосова (Килинг) Острва",
    "Democratic Republic of the Congo" : "Демократска Република Конго",
    "Central African Republic" : "Централноафричка Република",
    "Congo" : "Конго",
    "Switzerland" : "Швајцарска",
    "Cote d'Ivoire" : "Обала Слоноваче",
    "Cook Islands" : "Кукова Острва",
    "Chile" : "Чиле",
    "Cameroon" : "Камерун",
    "China" : "Кина",
    "Colombia" : "Колумбија",
    "Costa Rica" : "Костарика",
    "Cuba" : "Куба",
    "Cabo Verde" : "Зеленортска острва",
    "Curaçao" : "Курасао",
    "Christmas Island" : "Ускршња острва",
    "Cyprus" : "Кипар",
    "Czech" : "Чешка",
    "Germany" : "Немачка",
    "Djibouti" : "Џибути",
    "Denmark" : "Данска",
    "Dominican Republic" : "Доминиканска Република",
    "Algeria" : "Алжир",
    "Ecuador" : "Еквадор",
    "Estonia" : "Естонија",
    "Egypt" : "Египат",
    "West Sahara" : "Западна Сахара",
    "Eritrea" : "Еритреја",
    "Spain" : "Шпанија",
    "Ethiopia" : "Етиопија",
    "Finland" : "Финска",
    "Fiji" : "Фиџи",
    "Falkland Islands" : "Фолкландска острва",
    "Micronesia" : "Микронезија",
    "Faroe Islands" : "Фарска Острва",
    "France" : "Француска",
    "Gabon" : "Габон",
    "United Kingdom" : "Уједињено Краљевство",
    "Grenada" : "Гренада",
    "Georgia" : "Грузија",
    "French Guiana" : "Француска Гвајана",
    "Guernsey" : "Гернзи",
    "Ghana" : "Гана",
    "Gibraltar" : "Гибралтар",
    "Greenland" : "Гренланд",
    "Gambia" : "Гамбија",
    "Guinea" : "Гвинеја",
    "Guadeloupe" : "Гвадалупе",
    "Equatorial Guinea" : "Екваторијална Гвинеја",
    "Greece" : "Грчка",
    "South Georgia and the South Sandwich Islands" : "Јужна Џорџија и Јужна Сендвичка острва",
    "Guatemala" : "Гватемала",
    "Guam" : "Гвам",
    "Guinea-Bissau" : "Гвинеја Бисао",
    "Guyana" : "Гвајана",
    "Hong Kong" : "Хонг Конг",
    "Heard Island and McDonald Islands" : "Острво Херд и острва Макдоналд",
    "Honduras" : "Хондурас",
    "Croatia" : "Хрватска",
    "Haiti" : "Хаити",
    "Hungary" : "Мађарска",
    "Indonesia" : "Индонезија",
    "Ireland" : "Ирска",
    "Israel" : "Израел",
    "Isle of Man" : "Острво Мен",
    "India" : "Индија",
    "British Indian Ocean Territory" : "Британска територија Индијског океана",
    "Iraq" : "Ирак",
    "Iran" : "Иран",
    "Iceland" : "Исланд",
    "Italy" : "Италија",
    "Jamaica" : "Јамајка",
    "Jordan" : "Јордан",
    "Japan" : "Јапан",
    "Kenya" : "Кенија",
    "Kyrgyzstan" : "Киргистан",
    "Cambodia" : "Камбоџа",
    "Kiribati" : "Кирибати",
    "Comores" : "Комори",
    "Saint Kitts and Nevis" : "Сент Китс и Невис",
    "North Korea" : "Северна Кореја",
    "South Korea" : "Јужна Кореја",
    "Kuwait" : "Кувајт",
    "Cayman Islands" : "Кајманска острва",
    "Kazakhstan" : "Казахстан",
    "Laos" : "Лаос",
    "Lebanon" : "Либан",
    "Saint Lucia" : "Света Луција",
    "Liechtenstein" : "Лихтенштајн",
    "Sri Lanka" : "Шри Ланка",
    "Liberia" : "Либерија",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литванија",
    "Luxembourg" : "Луксембург",
    "Latvia" : "Летонија",
    "Libya" : "Либија",
    "Morocco" : "Мароко",
    "Monaco" : "Монако",
    "Moldova" : "Молдавија",
    "Montenegro" : "Црна Гора",
    "Saint Martin" : "Свети Мартин (Кариби)",
    "Madagascar" : "Мадагаскар",
    "Marshall Islands" : "Маршалска Острва",
    "Macedonia" : "Македонија",
    "Mali" : "Мали",
    "Myanmar" : "Мјанмар",
    "Mongolia" : "Монголија",
    "Macao" : "Макао",
    "Northern Mariana Islands" : "Северна Маријанска Острва",
    "Mauritania" : "Мауританија",
    "Montserrat" : "Монтсерат",
    "Malta" : "Малта",
    "Mauritius" : "Маурицијус",
    "Maldives" : "Малдиви",
    "Malawi" : "Малави",
    "Mexico" : "Мексико",
    "Malaysia" : "Малезија",
    "Mozambique" : "Мозамбик",
    "Namibia" : "Намибија",
    "New Caledonia" : "Нова Каледонија",
    "Niger" : "Нигер",
    "Norfolk Island" : "Острво Норфок",
    "Nigeria" : "Нигерија",
    "Nicaragua" : "Никарагва",
    "Netherlands" : "Холандија",
    "Norway" : "Норвешка",
    "Nepal" : "Непал",
    "Nauru" : "Науру",
    "Niue" : "Нијуе",
    "New Zealand" : "Нови Зеланд",
    "Oman" : "Оман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "French Polynesia" : "Француска Полинезија",
    "Papua New Guinea" : "Папуа Нова Гвинеја",
    "Philippines" : "Филипини",
    "Pakistan" : "Пакистан",
    "Poland" : "Пољска",
    "Saint Pierre and Miquelon" : "Сен Пјер и Микелон",
    "Pitcairn" : "Питкерн",
    "Puerto Rico" : "Порторико",
    "Palestine" : "Палестина",
    "Portugal" : "Португалија",
    "Palau" : "Палау",
    "Paraguay" : "Парагвај",
    "Qatar" : "Катар",
    "Réunion" : "Реинион",
    "Romania" : "Румунија",
    "Serbia" : "Србија",
    "Russia" : "Русија",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудијска Арабија",
    "Solomon Islands" : "Соломонска Острва",
    "Seychelles" : "Сејшели",
    "Sudan" : "Судан",
    "Sweden" : "Шведска",
    "Singapore" : "Сингапур",
    "Saint Helena, Ascension and Tristan da Cunha" : "Света Јелена, Асенсион и Тристан да Куња",
    "Slovenia" : "Словенија",
    "Svalbard and Jan Mayen" : "Свалбард и Јан Мајен острва",
    "Slovakia" : "Словачка",
    "Sierra Leone" : "Сијера Леоне",
    "San Marino" : "Сан Марино",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомалија",
    "Suriname" : "Суринам",
    "South Sudan" : "Јужни Судан",
    "Sao Tome and Principe" : "Сао Томе и Принципе",
    "El Salvador" : "Ел Салвадор",
    "Sint Maarten" : "Свети Мартин (Холандија)",
    "Syria" : "Сирија",
    "Swaziland" : "Свазиленд",
    "Turks and Caicos Islands" : "Теркс и Кејкос",
    "Chad" : "Чад",
    "Fr. S. Antarctic Lands" : "Француске јужне и антарктичке земље",
    "Togo" : "Того",
    "Thailand" : "Тајланд",
    "Tajikistan" : "Таџикистан",
    "Tokelau" : "Токелау",
    "Timor-Leste" : "Источни Тимор",
    "Turkmenistan" : "Туркменистан",
    "Tunisia" : "Тунис",
    "Tonga" : "Тонга",
    "Turkey" : "Турска",
    "Trinidad and Tobago" : "Тринидад и Тобаго",
    "Tuvalu" : "Тувалу",
    "Taiwan" : "Тајван",
    "Tanzania" : "Танзанија",
    "Ukraine" : "Украјина",
    "Uganda" : "Уганда",
    "United States Minor Outlying Islands" : "Мала спољна острва Сједињених Држава",
    "United States" : "Сједињене Америчке Државе",
    "Uruguay" : "Уругвај",
    "Uzbekistan" : "Узбекистан",
    "Holy See" : "Света столица",
    "Saint Vincent and the Grenadines" : "Сент Винсент и Гренадини",
    "Venezuela" : "Венецуела",
    "Virgin Islands (British)" : "Девичанска Острва (британска)",
    "Virgin Islands (U.S.)" : "Девичанска Острва (америчка)",
    "Vietnam" : "Вијетнам",
    "Vanuatu" : "Вануату",
    "Wallis and Futuna" : "Валис и Футуна",
    "Samoa" : "Самоа",
    "Yemen" : "Јемен",
    "Mayotte" : "Мајот",
    "South Africa" : "Јужноафричка република",
    "Zambia" : "Замбија",
    "Zimbabwe" : "Зимбабве"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
